#!/usr/bin/env python3

import paho.mqtt.client as paho
import json
import time
import sys
import struct
import logging

FORMAT = '%(message)s'
logging.basicConfig(format=FORMAT)
logger = logging.getLogger(__name__)
logger.setLevel( logging.DEBUG )

def on_message(client, userdata, msg):
    """
    Function that gets called for every message you have subscribed to.
    msg.payload and msg.topic are available
    """
    logger.debug( "[on_message] {} {}".format(msg.payload, msg.topic) )

def on_connect(client, userdata, flags, rc):
    """
    When we are connected, we can subscribe to topics.
    Due to clean_session=True we have to do it on every connect

    NOTES:

    - qos=2 -> receive every message exactly once
    - topics have the following scheme:
      - <module>/<hostname>/[<id>/]/<property>
    - The $SYS topic can be used to identify all devices currently connected to the broker!
    """
    logger.debug( "[on_connect] " )
    #client.subscribe("sht21/+/temp",qos=2)
    #client.subscribe("sht21/+/humidity",qos=2)
    #client.subscribe("ds1820/+/+/temp",qos=2)
    client.subscribe("$SYS/broker/connection/+/state")

def on_disconnect(client, userdata, rc):
    """
    Called when the connection is interrupted
    """
    logger.debug( "[on_disconnect]" )

"""
by default, the broker will cache the topics we subscribed to.
clean_session=True will clear old data.
"""
client = paho.Client(client_id="logger", clean_session=True)
client.connect( sys.argv[1], port=int(sys.argv[2]), keepalive=5 )
"""
Setup callbacks
"""
client.on_message = on_message
client.on_connect = on_connect
client.on_disconnect = on_disconnect

"""
NOTE: there are other methods, such as loop_start() to be used in multithreading.
Additionally, loop_forever will not automatically handle re-connects.
"""
client.loop_forever()
